pub(crate) enum PrePostIteration<T: Clone> {
Enter(T),
Leave(T),
}Expand description
An Item in an traversal that is both pre-order and post-order. Each iteration
of the traversal is either an record of entering a node or a leaving a node during
the course of traversal.
Variants
Enter(T)
The traversal encountered this node for the first time. This happens before traversing the node’s descendants.
Leave(T)
The traversal is leaving this node. This happens after traversing the node’s descendants.